//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Filename       : $RCSfile: N_ANP_Op.C,v $
//
// Purpose        : Provide tools for accessing output data in parallel or
//                  serial
//
// Special Notes  :
//
// Creator        : David Baur
//
// Creation Date  : 11/15/2013
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.2 $
//
// Revision Date  : $Date: 2015/04/08 19:18:20 $
//
// Current Owner  : $Author: tvrusso $
//-----------------------------------------------------------------------------

#include <Xyce_config.h>

#include <N_ANP_Op.h>
#include <N_ANP_AnalysisManager.h>

namespace Xyce {
namespace Analysis {

//-----------------------------------------------------------------------------
// Function      : AnalysisInitialTimeOp::get
// Purpose       : get the initial time from the analysis manager
// Special Notes : 
// Scope         : public
// Creator       : David Baur, Raytheon
// Creation Date : 11/10/2014
//-----------------------------------------------------------------------------
complex
AnalysisInitialTimeOp::get(const AnalysisInitialTimeOp &op, const Util::Op::OpData &op_data)
{
  return op.analysisManager_.getInitialTime();
}


//-----------------------------------------------------------------------------
// Function      : AnalysisFinalTimeOp::get
// Purpose       : get the final time from the analysis manager
// Special Notes : 
// Scope         : public
// Creator       : David Baur, Raytheon
// Creation Date : 11/10/2014
//-----------------------------------------------------------------------------
complex
AnalysisFinalTimeOp::get(const AnalysisFinalTimeOp &op, const Util::Op::OpData &op_data)
{
  return op.analysisManager_.getFinalTime();
}

} // namespace Device
} // namespace Xyce
