//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Filename       : $RCSfile: N_IO_FunctionBlock.h,v $
//
// Purpose        : Declare an N_IO_FunctionBlock instantiations of which are
//                  associated with netlist .FUNC lines.
//
// Special Notes  :
//
// Creator        : Lon Waters, SNL
//
// Creation Date  : 12/26/2001
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.29 $
//
// Revision Date  : $Date: 2015/05/13 22:28:56 $
//
// Current Owner  : $Author: dgbaur $
//-----------------------------------------------------------------------------

#ifndef N_IO_FUNCTIONBLOCK_H
#define N_IO_FUNCTIONBLOCK_H

#include <string>
#include <vector>

#include <N_IO_fwd.h>
#include <N_IO_SpiceSeparatedFieldTool.h>
#include <N_UTL_Pack.h> 

namespace Xyce {
namespace IO {

class FunctionBlock
{
  friend class Pack<FunctionBlock>;

public:
  FunctionBlock()
  {}

  FunctionBlock(
    const std::string & fileName,
    const TokenVector & parsedInputLine);

  FunctionBlock(FunctionBlock const& rhsFB);

  ~FunctionBlock()
  {}

  // Public data.
  TokenVector parsedLine;

  std::string functionName;

  std::string functionNameAndArgs;

  std::vector<std::string> functionArgs;

  std::string functionBody;

  // Public methods.

  void print();
  // Prints the details of an ParameterBlock to standard out.

  bool extractData();
  //- Extract model data from parsedLine using model metadata.

private:
  std::string netlistFilename_;
};

} // namespace IO
} // namespace Xyce

#endif

