//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Filename       : $RCSfile: N_IO_OutputterSensitivityPrn.h,v $
//
// Purpose        :
//
// Special Notes  :
//
// Creator        : Dave Baur
//
// Creation Date  :
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.18 $
//
// Revision Date  : $Date: 2015/10/27 19:10:30 $
//
// Current Owner  : $Author: tvrusso $
//-----------------------------------------------------------------------------

#ifndef Xyce_N_IO_OutputterSensitivityPrn_h
#define Xyce_N_IO_OutputterSensitivityPrn_h

#include <N_IO_OutputterLocal.h>

namespace Xyce {
namespace IO {
namespace Outputter {

//-----------------------------------------------------------------------------
// sensitivity outputters

class SensitivityPrn : public Interface
{
public:
  SensitivityPrn(Parallel::Machine comm, OutputMgr &output_manager, const PrintParameters &print_parameters);

  virtual ~SensitivityPrn();

private:
  SensitivityPrn(const SensitivityPrn &);
  SensitivityPrn &operator=(const SensitivityPrn &);

public:
  virtual void doSetAnalysisMode(Analysis::Mode analysis_mode)
  {
    printParameters_.analysisMode_ = analysis_mode;
  }

  virtual void doFinishOutput();

  virtual void doStartStep(int step, int max_step);

  virtual void doResetIndex();

  virtual void doSteppingComplete();

  virtual void doOutputTime(
    Parallel::Machine           comm, 
    const Linear::Vector &        solution_vector, 
    const Linear::Vector &        state_vector, 
    const Linear::Vector &        store_vector,
    const Linear::Vector &        lead_current_vector,
    const Linear::Vector &        junction_voltage_vector)
  {}

  virtual void doOutputFrequency(
    Parallel::Machine           comm,
    double                      frequency, 
    const Linear::Vector &        real_solution_vector,
    const Linear::Vector &        imaginary_solution_vector)
  {}

  virtual void doOutputNoise(
    Parallel::Machine   comm,
    double              frequency,
    double              totalOutputNoiseDens_, 
    double              totalInputNoiseDens_, 
    const std::vector<Xyce::Analysis::NoiseData*> & noiseDataVec_)
  {}

  virtual void doOutputHB(
    Parallel::Machine           comm,
    const std::vector<double> & timePoints,
    const std::vector<double> & freqPoints,
    const Linear::BlockVector &   timeDomainSolutionVec,
    const Linear::BlockVector &   freqDomainSolutionVecReal,
    const Linear::BlockVector &   freqDomainSolutionVecImaginary,
    const Linear::BlockVector &   timeDomainStoreVec,
    const Linear::BlockVector &   freqDomainStoreVecReal,
    const Linear::BlockVector &   freqDomainStoreVecImaginary,
    const Linear::BlockVector &   timeDomainLeadCurrentVec,
    const Linear::BlockVector &   freqDomainLeadCurrentVecReal,
    const Linear::BlockVector &   freqDomainLeadCurrentVecImaginary,
    const Linear::BlockVector &   timeDomainJunctionVoltageVec,
    const Linear::BlockVector &   freqDomainJunctionVoltageVecReal,
    const Linear::BlockVector &   freqDomainJunctionVoltageVecImaginary)
  {}

  virtual void doOutputMPDE(
    Parallel::Machine           comm,
    double                      time,
    const std::vector<double> & fast_time_points,
    const Linear::BlockVector &   solution_vector)
  {}

  virtual void doOutputHomotopy(
    Parallel::Machine comm,
    const std::vector<std::string> & parameter_names, 
    const std::vector<double> & param_values, 
    const Linear::Vector & solution_vector)
  {}

  virtual void doOutputSensitivity(
    Parallel::Machine           comm,
    const std::vector<double> & objective_values, 
    const std::vector<double> & direct_values, 
    const std::vector<double> & adjoint_values,
    const std::vector<double> & scaled_direct_values, 
    const std::vector<double> & scaled_adjoint_values,
    const Linear::Vector &        solution_vector,
    const Linear::Vector &        state_vector, 
    const Linear::Vector &        store_vector);

private:
  void sensitivityHeader(); 

private:
  OutputMgr &                   outputManager_;
  PrintParameters               printParameters_;
  std::string                   outFilename_;
  std::ostream *                os_;
  int                           printCount_;
  int                           index_;
  int                           currentStep_;
  int                           numberOfSteps_;

  std::vector<std::string>      sensParFullNames_;
  Table::ColumnList             columnList_;
  Util::Op::OpList              opList_;
};

} // namespace Outputter
} // namespace IO
} // namespace Xyce

#endif // Xyce_N_IO_OutputterSensitivityPrn_h
