//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2011  Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-------------------------------------------------------------------------
// Filename       : $RCSfile: N_IO_fwd.h,v $
//
// Purpose        : Forward declarations
//
// Special Notes  : Forward declaring everything as a class breaks if the implementation of the type changes (like during
//                  templatization)
//
// Creator        : David G. Baur  Raytheon  Sandia National Laboratories 1355 
//
// Creation Date  : 2013/04/18 18:01:27
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.39 $
//
// Revision Date  : $Date: 2015/08/04 19:43:20 $
//
// Current Owner  : $Author: hkthorn $
//-------------------------------------------------------------------------

#ifndef Xyce_N_IO_fwd_h
#define Xyce_N_IO_fwd_h

#if defined(HAVE_UNORDERED_MAP)
#include <unordered_map>
using std::unordered_map;
#elif defined(HAVE_TR1_UNORDERED_MAP)
#include <tr1/unordered_map>
using std::tr1::unordered_map;
#else
#error neither unordered_map or tr1/unordered_map found
#endif

#if defined(HAVE_UNORDERED_SET)
#include <unordered_set>
using std::unordered_set;
#elif defined(HAVE_TR1_UNORDERED_SET)
#include <tr1/unordered_set>
using std::tr1::unordered_set;
#else
#error neither unordered_set or tr1/unordered_set found
#endif

#include <map>
#include <string>
#include <vector>
#include <utility>

#include <N_UTL_NoCase.h>
#include <N_UTL_NetlistLocation.h>

namespace Xyce {
namespace IO {

namespace PrintType {
enum PrintType {NONE, DC, TRAN, AC, AC_IC, HB, HB_TD, HB_FD, HB_IC, HB_STARTUP, HOMOTOPY, MPDE, MPDE_IC, MPDE_STARTUP, RAW_OVERRIDE, SENS, NOISE};
}

namespace PreprocessType {
enum PreprocessType {REDUNDANT_C, REDUNDANT_D, REDUNDANT_I, REDUNDANT_L, REDUNDANT_M, REDUNDANT_Q, REDUNDANT_R, REDUNDANT_V, REPLACE_GROUND, NUM_PREPROCESS};
}

class ActiveOutput;
class CircuitBlock;
class CircuitContext;
class CircuitMetadata;
class CmdParse;
class DeviceBlock;
class DistributionTool;
class FourierMgr;
class FunctionBlock;
class InitialConditionsManager;
class HangingResistor;
class NetlistImportTool;
class LoadManager;
class Objective;
class ObjectiveManager;
class OutputMOR;
class OutputMOR;
class OutputMgr;
class OutputResponse;
class OutputResults;
class ParameterBlock;
class PkgOptionsMgr;
class RestartMgr;
class RestartNode;
class SpiceSeparatedFieldTool;
struct StringToken;
struct DeviceMetadata;
struct PkgOptionsReg;

class OutputFileBase;

struct PrintParameters;
struct Table;

typedef StringToken Token;
typedef std::vector<Token> TokenVector;

typedef bool (*ParseFunction)(PkgOptionsMgr &options_manager, CircuitBlock &circuit_block, const std::string &netlist_filename, const TokenVector &parsed_line);

typedef std::pair<double, double> Interval;
typedef std::vector<Interval> IntervalVector;
typedef unordered_map<std::string, std::string, HashNoCase, EqualNoCase> AliasNodeMap;
typedef std::pair<std::ifstream *, SpiceSeparatedFieldTool *> FileSSFPair;

typedef std::map<std::string, Objective> ObjectiveMap;

namespace Measure {
class Manager;
}

class FourierMgr;

namespace OutputType {
enum OutputType {DC, TRAN, AC, AC_IC, HB_FD, HB_TD, HB_IC, HB_STARTUP, DCOP, HOMOTOPY, MPDE, MPDE_IC, MPDE_STARTUP, SENS, NOISE};
}

typedef std::map<OutputType::OutputType, std::vector<PrintParameters> > OutputParameterMap;

// Information stored about the include file during the first pass of the parser.
struct IncludeFileInfo
{
  IncludeFileInfo()
  :
  numDevices(0),
  numSubckts(0),
  numModels(0),
  numSUBCKTdefs(0),
  inSUBCKT(false),
  parentSUBCKT("")
  {}

  virtual ~IncludeFileInfo()
  {}

  int numDevices;
  int numSubckts;
  int numModels;
  int numSUBCKTdefs;
  bool inSUBCKT;
  std::string parentSUBCKT;
  NetlistLocation location;
};

} // namespace IO
} // namespace Xyce

#endif // Xyce_N_IO_fwd_h

