//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright(C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-------------------------------------------------------------------------
// Filename       : $RCSfile: N_IO_OutputterNoise.C,v $
//
// Purpose        :
//
// Special Notes  :
//
// Creator        : Eric Keiter
//
// Creation Date  :
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.3 $
//
// Revision Date  : $Date: 2015/04/08 19:18:27 $
//
// Current Owner  : $Author: tvrusso $
//-------------------------------------------------------------------------

#include <Xyce_config.h>

#include <N_ERH_ErrorMgr.h>
#include <N_IO_OutputMgr.h>
#include <N_IO_OutputterNoise.h>
#include <N_IO_OutputterNoisePrn.h>
#include <N_IO_OutputterNoiseTecplot.h>

namespace Xyce {
namespace IO {
namespace Outputter {

void enableNoiseOutput(Parallel::Machine comm, OutputMgr &output_manager, Analysis::Mode analysis_mode)
{
  std::pair<OutputParameterMap::const_iterator, bool> result = output_manager.findOutputParameter(OutputType::NOISE);
  if (result.second)
  {
    for (std::vector<PrintParameters>::const_iterator it = (*result.first).second.begin(), end2 = (*result.first).second.end(); it != end2; ++it) {
      PrintParameters noise_print_parameters = (*it);

      output_manager.fixupPrintParameters(comm, noise_print_parameters);

      Outputter::Interface *outputter;
      if (noise_print_parameters.format_ == Format::STD) {
        outputter = new Outputter::NoisePrn(comm, output_manager, noise_print_parameters);
      }
      else if (noise_print_parameters.format_ == Format::TECPLOT) {
        outputter = new Outputter::NoiseTecPlot(comm, output_manager, noise_print_parameters);
      }
      else
      {
        Report::UserWarning0() << "Noise output cannot be written in " << noise_print_parameters.format_ << " format, using standard format";

        outputter = new Outputter::NoisePrn(comm, output_manager, noise_print_parameters);
      }

      output_manager.addOutputter(PrintType::NOISE, outputter);
    }
  }
}

} // namespace Outputter
} // namespace IO
} // namespace Xyce
