//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Filename       : $RCSfile: N_LAS_QueryUtil.h,v $
//
// Purpose        :
//
// Special Notes  :
//
// Creator        : Robert J. Hoekstra, SNL, Parallel Computational Sciences
//
// Creation Date  : 06/09/00
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.38 $
//
// Revision Date  : $Date: 2015/05/15 13:55:04 $
//
// Current Owner  : $Author: dgbaur $
//-----------------------------------------------------------------------------


#ifndef N_LAS_QueryUtil_h
#define N_LAS_QueryUtil_h 1

#include <string>
#include <vector>

#include <N_IO_fwd.h>
#include <N_UTL_fwd.h>

namespace Xyce {
namespace Linear {

//-----------------------------------------------------------------------------
// Class         : QueryUtil
// Purpose       : Abstract class for Query Utility used by LAS to
//                 determine parameters for linear system instantiation
// Special Notes :
// Creator       : Rob Hoekstra, SNL, Parallel Computational Sciences
// Creation Date : 6/09/00
//-----------------------------------------------------------------------------
class QueryUtil
{
public:
  static void populateMetadata(IO::PkgOptionsMgr &options_manager);

  // Default constructor
  QueryUtil();

  // Destructor
  virtual ~QueryUtil() {}

  // Method to register the package options manager
  bool registerTimeOptions(const Util::OptionBlock & OB) { return true; }
  bool registerOptions(const Util::OptionBlock & OB);
     
  // Setup row/col data for linear solver including reorder.
  virtual bool setupRowCol() = 0;
  //
  // Get access to the supernode flag
  virtual bool supernodeFlag() { return supernode_; }
  //
  // Get access to the names file flag
  virtual bool namesFileFlag() { return namesFile_; }
  
  //------ accessor methods
  virtual int numGlobalRows() const = 0;
  virtual int numLocalRows() const { return numGlobalRows(); }
  virtual int numExternRows() const { return 0; }
  virtual int numGlobalExternRows() const { return 0; }

  virtual int numGlobalStateVars() const = 0;
  virtual int numLocalStateVars() const { return numGlobalStateVars(); }
  virtual int numExternStateVars() const { return 0; }
  virtual int numGlobalExternStateVars() const { return 0; }

  virtual int numGlobalStoreVars() const = 0;
  virtual int numLocalStoreVars() const { return numGlobalStoreVars(); }
  virtual int numExternStoreVars() const { return 0; }
  virtual int numGlobalExternStoreVars() const { return 0; }
  
  virtual int numGlobalLeadCurrentVars() const = 0;
  virtual int numLocalLeadCurrentVars() const { return numGlobalLeadCurrentVars(); }
  virtual int numExternLeadCurrentVars() const { return 0; }
  virtual int numGlobalExternLeadCurrentVars() const { return 0; }

  virtual int numGlobalNZs() const = 0;
  virtual int numLocalNZs() const { return numGlobalNZs(); }

  virtual const std::vector<int> & rowList_GID() const = 0;
  virtual const std::vector< std::pair<int,int> > & rowList_ExternGID() const
  {
    static std::vector< std::pair<int,int> > dummy;
    return dummy;
  }

  virtual const std::vector<int> & rowList_StateGID() const = 0;
  virtual const std::vector< std::pair<int,int> > & rowList_ExternStateGID() const
  {
    static std::vector< std::pair<int,int> > dummy;
    return dummy;
  }

  virtual const std::vector<int> & rowList_StoreGID() const = 0;
  virtual const std::vector< std::pair<int,int> > & rowList_ExternStoreGID() const
  {
    static std::vector< std::pair<int,int> > dummy;
    return dummy;
  }

  virtual const std::vector<int> & rowList_LeadCurrentGID() const = 0;
  virtual const std::vector< std::pair<int,int> > & rowList_ExternLeadCurrentGID() const
  {
    static std::vector< std::pair<int,int> > dummy;
    return dummy;
  }
  
  virtual const std::vector<int> & rowList_NumNZs() const = 0;

  virtual const std::vector< std::vector<int> > & rowList_ColList() const = 0;

  virtual const std::vector<int> & vnodeGIDVec() const = 0;

  virtual const std::vector<int> & vsrcGIDVec() const = 0;

  virtual const std::vector<int> & nonlinGIDVec() const = 0;

  virtual const std::vector<char> & rowList_VarType() const = 0;

protected:
  bool checkConnectivity_;
  bool supernode_;
  bool namesFile_;
};

bool registerPkgOptionsMgr(QueryUtil &linear_solve_utility, IO::PkgOptionsMgr &options_manager);

} // namespace Linear
} // namespace Xyce

#endif
