//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Filename       : $RCSfile: N_LAS_Vector.h,v $
//
// Purpose        : Specification file for the Abstract interface to the
//                  vector types (RDP, RSP, CDP or CSP).
//
// Special Notes  :
//
// Creator        : Scott A. Hutchinson, SNL, Computational Sciences
//
// Creation Date  : 10/13/00
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.31 $
//
// Revision Date  : $Date: 2015/04/08 19:18:28 $
//
// Current Owner  : $Author: tvrusso $
//-----------------------------------------------------------------------------

#ifndef Xyce_N_LAS_Vector_h
#define Xyce_N_LAS_Vector_h

#include <string>
#include <map>

#include <N_LAS_MultiVector.h>

#include <Epetra_Vector.h>

class N_PDS_ParMap;

namespace Xyce {
namespace Linear {

//-----------------------------------------------------------------------------
// Class         : Vector
// Purpose       : Provides an abstract interface for the vector type (RDP,
//                 RSP, CDP or CSP).
// Special Notes :
// Creator       : Scott A. Hutchinson, SNL, Compuational Sciences
// Creation Date : 10/13/00
//-----------------------------------------------------------------------------
class Vector : public MultiVector
{

public:

  // Constructors to map to Petra constructors.
  Vector(N_PDS_ParMap & map)
  : MultiVector(map, 1)
  {}

  Vector( N_PDS_ParMap & map, N_PDS_ParMap & ol_map )
  : MultiVector( map, ol_map, 1 )
  {}

  //Copy constructor
  Vector( const Vector & right )
  : MultiVector(right)
  {}

  Vector( Epetra_Vector * origV, bool isOwned);

  // Constructor takes the oMultiVector and generates the aMultiVector
  Vector( Epetra_Vector * overlapMV, Epetra_Map& parMap, bool isOwned = true );

  // Destructor
  virtual ~Vector() {}

  // Operation: operator []
  double & operator[] (int index)
  {
    return (*oMultiVector_)[0][index];
  }

  // Operation: operator []
  const double & operator[] (int index) const
  {
    return (*oMultiVector_)[0][index];
  }
};

} // namespace Linear
} // namespace Xyce

#endif

