//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-------------------------------------------------------------------------
// Filename       : $RCSfile: N_NLS_NOX_AugmentLinSys_OPStart.h,v $
//
// Purpose        : Concrete class for augmenting the Jacobian for
//                  pseudo-transient solves.
//
// Special Notes  :
//
// Creator        : Dave Shirley, PSSI
//
// Creation Date  : 05/08/06
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.23 $
//
// Revision Date  : $Date: 2015/04/08 19:18:29 $
//
// Current Owner  : $Author: tvrusso $
//-------------------------------------------------------------------------


#ifndef Xyce_N_NLS_NOX_AugmentLinSys_OPStart_h
#define Xyce_N_NLS_NOX_AugmentLinSys_OPStart_h

#include <set>

#include <N_UTL_fwd.h>

#include "N_NLS_NOX_AugmentLinSys.h"
#include "N_PDS_ParMap.h"
#include "N_PDS_ParComm.h"

#include <N_IO_InitialConditions.h>

class Epetra_MapColoring;

//-----------------------------------------------------------------------------
// Class         : N_NLS::NOX::AugmentLinSysOPStart
// Purpose       :
// Creator       : Roger Pawlowski, SNL, 9233
// Creation Date :
//-----------------------------------------------------------------------------
namespace Xyce {
namespace Nonlinear {
namespace N_NLS_NOX {

class AugmentLinSysOPStart : public AugmentLinSys {

public:
    AugmentLinSysOPStart(Xyce::IO::InitialConditionsData::NodeNamePairMap &, const Xyce::NodeNameMap &, N_PDS_Comm *);

  //! Dtor.
  ~AugmentLinSysOPStart();

  void setProgressVariable(double dummy) {return;}

  void augmentResidual(const Xyce::Linear::Vector * solution, Xyce::Linear::Vector * residual_vector);

  void augmentJacobian(Xyce::Linear::Matrix * jacobian);

 private:

  //! map of specified variables
    Xyce::IO::InitialConditionsData::NodeNamePairMap & op_;
  const Xyce::NodeNameMap & allNodes_;

  bool skipSet;
  std::set<int> skipLID;
  std::set<int> skipGID;

  Xyce::Linear::Vector* residualPtr_;
  const Xyce::Linear::Vector* solutionPtr_;
  int rSize_;
  N_PDS_ParMap * pmap_;
  N_PDS_Comm * pdsCommPtr_;
};

}}}

#endif

