//-----------------------------------------------------------------------------
// Copyright Notice
//
//   Copyright 2002 Sandia Corporation. Under the terms
//   of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S.
//   Government retains certain rights in this software.
//
//    Xyce(TM) Parallel Electrical Simulator
//    Copyright (C) 2002-2015 Sandia Corporation
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------

//-------------------------------------------------------------------------
// Filename       : $RCSfile: N_TOP_LSUtilFactory.C,v $
//
// Purpose        : Implementation file for the interface for creating linear
//                  algebra objects using the GoF Abstract Factory design
//                  pattern.  It must be used with a compatible linear algebra
//                  package (e.g., Trilinos/Petra to provide the concrete
//                  implementations.
//
// Special Notes  :
//
// Creator        : Scott A. Hutchinson, SNL, Parallel Computational Sciences
//
// Creation Date  : 05/20/00
//
// Revision Information:
// ---------------------
//
// Revision Number: $Revision: 1.2 $
//
// Revision Date  : $Date: 2015/04/08 19:18:31 $
//
// Current Owner  : $Author: tvrusso $
//-------------------------------------------------------------------------

#include <Xyce_config.h>


// ---------- Standard Includes ----------

// ----------   Xyce Includes   ----------

#include <N_TOP_LSUtilFactory.h>
#include <N_IO_CmdParse.h>
#include <N_PDS_Comm.h>
#include <N_PDS_Manager.h>
#include <N_TOP_SerialLSUtil.h>
#include <N_TOP_ParLSUtil.h>
#include <N_TOP_Topology.h>
#include <N_LAS_QueryUtil.h>

namespace Xyce {
namespace Topo {

//-----------------------------------------------------------------------------
// Function      : LSUtilFactory::newLSUtil
// Purpose       : 
// Special Notes :
// Scope         : Public
// Creator       : Heidi K. Thornquist, SNL, Computational Sciences
// Creation Date : 02/23/15
//-----------------------------------------------------------------------------
Linear::QueryUtil * LSUtilFactory::newLSUtil( Topology &topology, 
                                              const IO::CmdParse &command_line, 
                                              IO::HangingResistor &hanging_resistor, 
                                              N_PDS_Manager &pds_manager )
{
  if ((pds_manager.getPDSComm())->isSerial())
  {
    return ( new Xyce::Topo::SerialLSUtil( topology, command_line, hanging_resistor, pds_manager ) );
  }
  else
  {
    return ( new Xyce::Topo::ParLSUtil( topology, command_line, hanging_resistor, pds_manager ) );
  }
} 

} // namespace Topo
} // namespace Xyce
